==> haskell-hpack-0.28.2-42-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hpack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hpack
version: 0.28.2
id: hpack-0.28.2-DGrXba9TOylAVOrWcnvBfX
key: hpack-0.28.2-DGrXba9TOylAVOrWcnvBfX
license: MIT
maintainer: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/hpack#readme
synopsis: An alternative format for Haskell packages
description:
    See README at <https://github.com/sol/hpack#readme>
category: Development
abi: 69a50c14914601aa0da47ac4f6263c09
exposed: True
exposed-modules:
    Hpack Hpack.Config Hpack.Render Hpack.Yaml
hidden-modules: Data.Aeson.Config.FromValue
                Data.Aeson.Config.Parser Data.Aeson.Config.Types
                Data.Aeson.Config.Util Hpack.CabalFile Hpack.Defaults Hpack.Haskell
                Hpack.Options Hpack.Render.Dsl Hpack.Render.Hints
                Hpack.Syntax.Defaults Hpack.Syntax.Dependency Hpack.Syntax.Git
                Hpack.Utf8 Hpack.Util Paths_hpack
import-dirs: /usr/lib/ghc-8.4.3/site-local/hpack-0.28.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/hpack-0.28.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hpack-0.28.2
hs-libraries: HShpack-0.28.2-DGrXba9TOylAVOrWcnvBfX
depends:
    Cabal-2.2.0.1 Glob-0.9.2-AbjvDlFSYnKBsiDSJQ0XCU
    aeson-1.3.1.1-TT45dpTFlI3IDS4gOrl3y base-4.11.1.0
    bifunctors-5.5.2-FnSrewG1ygu7QtjW8DMYvn bytestring-0.10.8.2
    containers-0.5.11.0 cryptonite-0.25-90uxV0bWEYmfC6QouwM7s
    deepseq-1.4.3.0 directory-1.3.1.5 filepath-1.4.2
    http-client-0.5.13.1-E2oTnwSZQmdIh914s8ng5x
    http-client-tls-0.3.5.3-1zpUVPwvh5wHxc5Fk2W0Kx
    http-types-0.12.1-K1Di4IDpOnPEbRIeR3j5Gc pretty-1.1.3.6
    scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul text-1.2.3.0
    transformers-0.5.5.0
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    yaml-0.8.31-8lmUQZqhgVSG966TPhCNOy
abi-depends: Cabal-2.2.0.1=cb731d19f27640e4ae6e4fb9c679c02f
             Glob-0.9.2-AbjvDlFSYnKBsiDSJQ0XCU=fe90daae121092f087f19649a03fe024
             aeson-1.3.1.1-TT45dpTFlI3IDS4gOrl3y=07d229e9fe1ca7309e20349a237239ed
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bifunctors-5.5.2-FnSrewG1ygu7QtjW8DMYvn=af8c18d7ff712debb5710f9dacbefdcf
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             cryptonite-0.25-90uxV0bWEYmfC6QouwM7s=ab6703e009204c8918b02064ccbf4d84
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             http-client-0.5.13.1-E2oTnwSZQmdIh914s8ng5x=7bfdf5a067b9b51eacef98e312bdcb38
             http-client-tls-0.3.5.3-1zpUVPwvh5wHxc5Fk2W0Kx=c707f91820faa43557a62b2504200a19
             http-types-0.12.1-K1Di4IDpOnPEbRIeR3j5Gc=48aca1d059bd297a17f6a458e8d85d56
             pretty-1.1.3.6=242598bba36778e604a1e89d5c7ce1a8
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=dc9b33f81f401bd0ab050d9bb851ae71
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
             yaml-0.8.31-8lmUQZqhgVSG966TPhCNOy=0c0d3b06ec48a30f67e50d3914487783
haddock-interfaces: /usr/share/doc/haskell-hpack/html/hpack.haddock
haddock-html: /usr/share/doc/haskell-hpack/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hpack-0.28.2-43-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hpack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hpack
version: 0.28.2
id: hpack-0.28.2-KD2sP7NB8JABgMBbgUm6Yp
key: hpack-0.28.2-KD2sP7NB8JABgMBbgUm6Yp
license: MIT
maintainer: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/hpack#readme
synopsis: An alternative format for Haskell packages
description:
    See README at <https://github.com/sol/hpack#readme>
category: Development
abi: beb1162df58e9865d703344bcc557956
exposed: True
exposed-modules:
    Hpack Hpack.Config Hpack.Render Hpack.Yaml
hidden-modules: Data.Aeson.Config.FromValue
                Data.Aeson.Config.Parser Data.Aeson.Config.Types
                Data.Aeson.Config.Util Hpack.CabalFile Hpack.Defaults Hpack.Haskell
                Hpack.Options Hpack.Render.Dsl Hpack.Render.Hints
                Hpack.Syntax.Defaults Hpack.Syntax.Dependency Hpack.Syntax.Git
                Hpack.Utf8 Hpack.Util Paths_hpack
import-dirs: /usr/lib/ghc-8.4.3/site-local/hpack-0.28.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/hpack-0.28.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hpack-0.28.2
hs-libraries: HShpack-0.28.2-KD2sP7NB8JABgMBbgUm6Yp
depends:
    Cabal-2.2.0.1 Glob-0.9.2-AbjvDlFSYnKBsiDSJQ0XCU
    aeson-1.3.1.1-TT45dpTFlI3IDS4gOrl3y base-4.11.1.0
    bifunctors-5.5.2-FnSrewG1ygu7QtjW8DMYvn bytestring-0.10.8.2
    containers-0.5.11.0 cryptonite-0.25-90uxV0bWEYmfC6QouwM7s
    deepseq-1.4.3.0 directory-1.3.1.5 filepath-1.4.2
    http-client-0.5.13.1-B8ymBgXYvEy5Ee96ZIFRim
    http-client-tls-0.3.5.3-DICwM9bpjP9DfjTwEdO1Cl
    http-types-0.12.1-K1Di4IDpOnPEbRIeR3j5Gc pretty-1.1.3.6
    scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul text-1.2.3.0
    transformers-0.5.5.0
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    yaml-0.8.31-8lmUQZqhgVSG966TPhCNOy
abi-depends: Cabal-2.2.0.1=cb731d19f27640e4ae6e4fb9c679c02f
             Glob-0.9.2-AbjvDlFSYnKBsiDSJQ0XCU=fe90daae121092f087f19649a03fe024
             aeson-1.3.1.1-TT45dpTFlI3IDS4gOrl3y=07d229e9fe1ca7309e20349a237239ed
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bifunctors-5.5.2-FnSrewG1ygu7QtjW8DMYvn=af8c18d7ff712debb5710f9dacbefdcf
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             cryptonite-0.25-90uxV0bWEYmfC6QouwM7s=ab6703e009204c8918b02064ccbf4d84
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             http-client-0.5.13.1-B8ymBgXYvEy5Ee96ZIFRim=9012795347b01804c5abe898411d88c8
             http-client-tls-0.3.5.3-DICwM9bpjP9DfjTwEdO1Cl=46cab2af4061ff0caf553ea44e1db7be
             http-types-0.12.1-K1Di4IDpOnPEbRIeR3j5Gc=48aca1d059bd297a17f6a458e8d85d56
             pretty-1.1.3.6=242598bba36778e604a1e89d5c7ce1a8
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=dc9b33f81f401bd0ab050d9bb851ae71
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
             yaml-0.8.31-8lmUQZqhgVSG966TPhCNOy=0c0d3b06ec48a30f67e50d3914487783
haddock-interfaces: /usr/share/doc/haskell-hpack/html/hpack.haddock
haddock-html: /usr/share/doc/haskell-hpack/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
